@@ -389,16 +389,17 @@ class InputHipims:
         file_tag: str or list of str including
                   ['z', 'h', 'hU', 'manning', 'sewer_sink',
                         'cumulative_depth', 'hydraulic_conductivity',
-                        'capillary_head', 'water_content_diff'
+                        'capillary_head', 'water_content_diff',
                         'precipitation_mask', 'precipitation_source',
                         'boundary_condition', 'gauges_pos']
         """
         self._make_data_dirs()
         grid_files = InputHipims.grid_files
         if file_tag is None or file_tag == 'all': # write all files
-            file_tag_list = ['z', 'h', 'hU', 'manning', 'sewer_sink',
+            file_tag_list = ['z', 'h', 'hU', 'precipitation',
+                             'manning', 'sewer_sink',
                              'cumulative_depth', 'hydraulic_conductivity',
-                             'capillary_head', 'water_content_diff'
+                             'capillary_head', 'water_content_diff',
                              'precipitation_mask', 'precipitation_source',
                              'boundary_condition', 'gauges_pos']
             if self.num_of_sections > 1:
@@ -417,14 +418,14 @@ class InputHipims:
         for one_file in file_tag_list:
             if one_file in grid_files: # grid-based files
                 self.write_grid_files(one_file)
-            elif file_tag == 'boundary_condition':
+            elif one_file == 'boundary_condition':
                 self.write_boundary_conditions()
-            elif file_tag == 'precipitation_source':
+            elif one_file == 'precipitation_source':
                 self.write_rainfall_source()
-            elif file_tag == 'gauges_pos':
+            elif one_file == 'gauges_pos':
                 self.write_gauges_position()
             else:
-                raise ValueError('file_tag is not recognized')
+                raise ValueError(one_file+' is not recognized')
 
     def write_grid_files(self, file_tag, is_single_gpu=False):
         """Write grid-based files
@@ -526,7 +527,7 @@ class InputHipims:
                 file_name = obj_section.data_folders['mesh']+'DEM.txt'
                 obj_section.DEM.write_asc(file_name)
         self.Summary.write_readme(self.case_folder+'/readme.txt')
-        print('DEM.txt created')
+#        print('DEM.txt created')
     
     def write_runtime_file(self, time_values=None):
         """ write times_setup.dat file
