@@ -64,8 +64,8 @@ class OutputHipims:
             # case_folder, num_of_sections, header
             self.case_folder = input_obj.case_folder
             self.num_of_sections = input_obj.num_of_sections
-            self.header = input_obj.Raster.header
-            self.dem_array = input_obj.Raster.array
+            self.header = input_obj.header
+            self.dem_array = input_obj.DEM.array
             self.output_folder = input_obj.data_folders['output']
             self.input_folder = input_obj.data_folders['input']
             self.Summary = input_obj.Summary
@@ -192,7 +192,7 @@ class OutputHipims:
             result_names = [result_names]
         for file_tag in result_names:
             grid_obj = self.read_grid_file(file_tag, compressed)
-            self.grid_results[file_tag] = grid_obj
+            self.grid_results[file_tag] = grid_obj.array
 
     def set_ref_datetime(self, date_time, str_format='%Y-%m-%d %H:%M:%S'):
         """Set the refernce datetime of the simulation
